summaryrefslogtreecommitdiff
path: root/chromium/net/base/cache_type.h
diff options
context:
space:
mode:
authorAllan Sandfeld Jensen <allan.jensen@qt.io>2018-08-28 15:28:34 +0200
committerAllan Sandfeld Jensen <allan.jensen@qt.io>2018-08-28 13:54:51 +0000
commit2a19c63448c84c1805fb1a585c3651318bb86ca7 (patch)
treeeb17888e8531aa6ee5e85721bd553b832a7e5156 /chromium/net/base/cache_type.h
parentb014812705fc80bff0a5c120dfcef88f349816dc (diff)
downloadqtwebengine-chromium-2a19c63448c84c1805fb1a585c3651318bb86ca7.tar.gz
BASELINE: Update Chromium to 69.0.3497.70
Change-Id: I2b7b56e4e7a8b26656930def0d4575dc32b900a0 Reviewed-by: Allan Sandfeld Jensen <allan.jensen@qt.io>
Diffstat (limited to 'chromium/net/base/cache_type.h')
-rw-r--r--chromium/net/base/cache_type.h14
1 files changed, 8 insertions, 6 deletions
diff --git a/chromium/net/base/cache_type.h b/chromium/net/base/cache_type.h
index 47bbf0b6b68..23995948c69 100644
--- a/chromium/net/base/cache_type.h
+++ b/chromium/net/base/cache_type.h
@@ -9,12 +9,14 @@ namespace net {
// The types of caches that can be created.
enum CacheType {
- DISK_CACHE, // Disk is used as the backing storage.
- MEMORY_CACHE, // Data is stored only in memory.
- MEDIA_CACHE, // Optimized to handle media files.
- APP_CACHE, // Backing store for an AppCache.
- SHADER_CACHE, // Backing store for the GL shader cache.
- PNACL_CACHE, // Backing store the PNaCl translation cache
+ DISK_CACHE, // Disk is used as the backing storage.
+ MEMORY_CACHE, // Data is stored only in memory.
+ MEDIA_CACHE, // Optimized to handle media files.
+ APP_CACHE, // Backing store for an AppCache.
+ SHADER_CACHE, // Backing store for the GL shader cache.
+ PNACL_CACHE, // Backing store the PNaCl translation cache
+ GENERATED_CODE_CACHE, // Backing store for data (like code for JavaScript)
+ // generated by renderer.
};
// The types of disk cache backend, only used at backend instantiation.